@@ -25,30 +25,18 @@
 
 gint glurp_connect();
 void glurp_disconnect();
-mpd_Status *get_status(gboolean standalone);
-void update_playlist();
+void update_playlist(long long oldid);
 void clear_playlist();
 void get_playlist_list();
 void clear_playlist_list();
 void load_playlist(gchar *name);
-GlurpSong *glurp_get_nth_song(gint n);
+mpd_Song *glurp_get_nth_song(gint n);
 gboolean check_mpd_error();
 void glurp_add_add_dir(gchar *path, GtkTreePath *gpath);
-void glurp_add_search_result_dir(const gchar *what, int type, GtkTreePath *gpath);
+void glurp_add_search_result_dir( const gchar *what, gint type, GtkTreePath *gpath);
 gboolean glurp_process_plchanges(mpd_Status *status);
 void glurp_update_song(mpd_Song *song);
-void glurp_trim_playlist_end(gint last);
-
-enum {
-    GLURP_CONN_STATE_DISCONNECTED,
-    GLURP_CONN_STATE_CONNECTING,
-    GLURP_CONN_STATE_CONNECTED,
-    GLURP_CONN_STATE_DISCONNECTING
-};
-
-#define DISCONNECTED	(glurp->conn_state == GLURP_CONN_STATE_DISCONNECTED)
-#define CONNECTING	(glurp->conn_state == GLURP_CONN_STATE_CONNECTING)
-#define CONNECTED	(glurp->conn_state == GLURP_CONN_STATE_CONNECTED)
-#define DISCONNECTING	(glurp->conn_state == GLURP_CONN_STATE_DISCONNECTING)
+void fix_playlist_length();
 
 #endif /* __COMM_H */
+// vim: et sw=2 smarttab
