@@ -23,37 +23,37 @@
 #include <glib.h>
 #include <glib/gprintf.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <string.h>
 #include <stdlib.h>
 
+#include "trayicon.h"
 #include "structs.h"
 #include "support.h"
 #include "conf.h"
 
 extern GlurpState *glurp;
-extern GladeXML *guixml;
+extern GtkBuilder *builder;
 
 const gboolean config_column_defaults[] = {
-    FALSE,	/* filename */
-    TRUE,	/* artist */
-    TRUE,	/* title */
-    FALSE,	/* album */
-    FALSE,	/* trackno */
-    FALSE,	/* name */
-    TRUE,	/* pl. pos. */
-    FALSE,	/* id */
+    FALSE,  /* filename */
+    TRUE,  /* artist */
+    TRUE,  /* title */
+    FALSE,  /* album */
+    FALSE,  /* trackno */
+    FALSE,  /* name */
+    TRUE,  /* pl. pos. */
+    FALSE,  /* id */
 };
 
 gboolean config_column_ready[] = {
-    FALSE,	/* filename */
-    FALSE,	/* artist */
-    FALSE,	/* title */
-    FALSE,	/* album */
-    FALSE,	/* trackno */
-    FALSE,	/* name */
-    FALSE,	/* pl. pos. */
-    FALSE,	/* id */
+    FALSE,  /* filename */
+    FALSE,  /* artist */
+    FALSE,  /* title */
+    FALSE,  /* album */
+    FALSE,  /* trackno */
+    FALSE,  /* name */
+    FALSE,  /* pl. pos. */
+    FALSE,  /* id */
 };
 
 GlurpConfig *config_init() {
@@ -68,12 +68,13 @@ GlurpConfig *config_init() {
   c->autoconnect = FALSE;
   c->playlist_vis_on_start = FALSE;
   c->time_display_left = FALSE;
-  c->refresh_rate = 500;
+  c->refresh_rate = 500.0;
   c->pos_x = -11000;
   c->pos_y = -11000;
   c->width = -1;
   c->height = -1;
   c->save_size = FALSE;
+  c->trayicon = FALSE;
 
   for( i = 0; i < PL_BOLD; i++ ) c->playlist_columns[i] = FALSE;
 
@@ -86,8 +87,10 @@ gboolean config_load() {
   gint i = 0;
 
   glurp->config = config_init();
-
-  conf_path = g_strdup_printf("%s/%s", g_strdup(g_get_home_dir()), GLURP_CONFIG_FILE);
+  if (glurp->alternate_config_file)
+    conf_path = g_strdup(glurp->alternate_config_file);
+  else
+    conf_path = g_strdup_printf("%s/%s", g_strdup(g_get_home_dir()), GLURP_CONFIG_FILE);
 
   if( g_file_test(conf_path, G_FILE_TEST_EXISTS) ) {
     if( !g_file_test(conf_path, G_FILE_TEST_IS_REGULAR) ) {
@@ -103,7 +106,6 @@ gboolean config_load() {
   } else {
     debug("Config file empty, continuing.");
     config_set_defaults();
-    config_columns_set_remaining();
 
     return TRUE;
   }
@@ -118,14 +120,10 @@ gboolean config_load() {
     i++;
   }
 
-  config_columns_set_remaining();
-
   return TRUE;
 }
 
 void config_load_item(const gchar *key, const gchar *value) {
-  gint i;
-
   debug("%s = %s", key, value);
 
   if(!strcmp(key, "server")) {
@@ -159,7 +157,7 @@ void config_load_item(const gchar *key, const gchar *value) {
   }
 
   if(!strcmp(key, "refresh-rate")) {
-    glurp->config->refresh_rate = atol(value);
+    glurp->config->refresh_rate = atof(value);
     if( glurp->config->refresh_rate < MIN_REFRESH_RATE ) glurp->config->refresh_rate = MIN_REFRESH_RATE;
     if( glurp->config->refresh_rate > MAX_REFRESH_RATE ) glurp->config->refresh_rate = MAX_REFRESH_RATE;
     return;
@@ -170,14 +168,6 @@ void config_load_item(const gchar *key, const gchar *value) {
     return;
   }
 
-  if(!strcmp(key, "playlist-columns")) {
-    for( i = 0; i < PL_BOLD; i++ ) {
-      glurp->config->playlist_columns[i] = yesno(atoi(g_strdup_printf("%c", value[i])));
-      config_column_ready[i] = TRUE;
-    }
-    return;
-  }
-
   if(!strcmp(key, "vis-id")) {
     glurp->config->playlist_columns[PL_POS] = yesno(atoi(value));
     config_column_ready[PL_ID] = TRUE;
@@ -209,6 +199,11 @@ void config_load_item(const gchar *key, const gchar *value) {
     return;
   }
 
+  if(!strcmp(key, "trayicon")) {
+    glurp->config->trayicon = yesno(atoi(value));
+    return;
+  }
+
   debug("Invalid config item, ignoring.");
   return;
 }
@@ -216,11 +211,13 @@ void config_load_item(const gchar *key, const gchar *value) {
 void config_save() {
   gchar *conf_path = NULL, *stream_history = NULL;
   FILE *f;
-  GtkWidget *window_main;
-  guint i;
-  gchar cols[PL_BOLD + 1] = "";
+  GtkWidget *window_main, *w;
+  gboolean vis;
 
-  conf_path = g_strdup_printf("%s/%s", g_strdup(g_get_home_dir()), GLURP_CONFIG_FILE);
+  if (glurp->alternate_config_file)
+    conf_path = g_strdup(glurp->alternate_config_file);
+  else
+    conf_path = g_strdup_printf("%s/%s", g_strdup(g_get_home_dir()), GLURP_CONFIG_FILE);
 
   if( g_file_test(conf_path, G_FILE_TEST_EXISTS) ) {
     if( !g_file_test(conf_path, G_FILE_TEST_IS_REGULAR) ) {
@@ -255,18 +252,22 @@ void config_save() {
     debug("autoconnect = %d", yesno(glurp->config->autoconnect));
   }
 
-  if( glurp->config->playlist_vis_on_start ) {
-    g_fprintf(f, "playlist-visible-on-start = %d\n", yesno(glurp->config->playlist_vis_on_start));
-    debug("playlist-visible-on-start = %d", yesno(glurp->config->playlist_vis_on_start));
-  }
+  w = GTK_WIDGET(gtk_builder_get_object(builder, "togglebutton_playlist"));
+//  if( glurp->config->playlist_vis_on_start ) {
+  if( (vis = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w))) ) {
+    debug("playlist visible");
+    g_fprintf(f, "playlist-visible-on-start = %d\n", yesno(vis));
+    debug("playlist-visible-on-start = %d", yesno(vis));
+  } else
+    debug("playlist not visible");
 
   if( glurp->config->time_display_left ) {
     g_fprintf(f, "time-display-left = %d\n", yesno(glurp->config->time_display_left));
     debug("time-display-left = %d", yesno(glurp->config->time_display_left));
   }
 
-  g_fprintf(f, "refresh-rate = %ld\n", glurp->config->refresh_rate);
-  debug("refresh-rate = %ld", glurp->config->refresh_rate);
+  g_fprintf(f, "refresh-rate = %f\n", glurp->config->refresh_rate);
+  debug("refresh-rate = %f", glurp->config->refresh_rate);
 
   if( glurp->stream_history ) {
     stream_history = dump_stream_history();
@@ -275,15 +276,15 @@ void config_save() {
     g_free(stream_history);
   }
 
-  window_main = glade_xml_get_widget(guixml, "glurp_window_main");
+  window_main = GTK_WIDGET(gtk_builder_get_object(builder, "glurp_window_main"));
+
 
-/*
   if( glurp->config->pos_x != -11000 && glurp->config->pos_y != -11000 ) {
     g_fprintf(f, "window-x = %d\nwindow-y = %d\n", glurp->config->pos_x, glurp->config->pos_y);
     debug("window-x = %d", glurp->config->pos_x);
     debug("window-y = %d", glurp->config->pos_y);
   }
-*/
+
 
   if( glurp->config->save_size ) {
     g_fprintf(f, "save-size = %d\n", yesno(glurp->config->save_size));
@@ -296,11 +297,10 @@ void config_save() {
     debug("height = %d", glurp->config->height);
   }
 
-  for( i = 0; i < PL_BOLD; i++ )
-    sprintf(cols + strlen(cols), "%d", glurp->config->playlist_columns[i]);
-
-  g_fprintf(f, "playlist-columns = %s", cols);
-  debug("playlist-columns = %s", cols);
+  if( glurp->config->trayicon ) {
+    g_fprintf(f, "trayicon = %d\n", yesno(glurp->config->trayicon));
+    debug("trayicon = %d", yesno(glurp->config->trayicon));
+  }
 
   debug("Config file saved");
 
@@ -311,11 +311,4 @@ void config_set_defaults() {
   if( glurp->config->server_host ) g_free(glurp->config->server_host);
   glurp->config->server_host = g_strdup("localhost");
 }
-
-void config_columns_set_remaining() {
-  gint i;
-
-  for( i = 0; i < PL_BOLD; i++ ) {
-    if( !config_column_ready[i] ) glurp->config->playlist_columns[i] = config_column_defaults[i];
-  }
-}
+// vim: et sw=2 smarttab
