@@ -27,8 +27,13 @@ gboolean glurp_init_gui();
 void populate_config();
 void store_config();
 
+void gui_show_song_name();
+void gui_check_scroll();
+
 void create_playlist_liststore();
-void add_song_to_gui_playlist(GlurpSong *s, gint pos);
+void attach_gui_playlist_liststore();
+void detach_gui_playlist_liststore();
+void add_song_to_gui_playlist(mpd_Song *s, gint pos);
 void populate_gui_playlist();
 
 void hide_gui_playlist();
@@ -74,23 +79,27 @@ void gui_add_fill_dir(GtkTreeIter *iter, gboolean silent);
 gboolean gui_get_iter_by_id(GtkTreeIter *iter, gint id);
 gboolean gui_get_iter_by_pos(GtkTreeIter *iter, gint pos);
 
-void gui_update_song(gint id);
-
-void gui_trim_playlist_end(gint last);
-
 void create_stream_liststore();
 void populate_stream_liststore();
 void stream_window_destroyed();
 
 gchar *get_selected_stream();
 
-void gui_refresh_playlist_columns();
-
 GtkMenu *populate_outputs_menu();
 
 gboolean on_menu_outputs_deactivate(GtkWidget *widget, gpointer data);
 gboolean on_menu_output_activate(GtkWidget *widget, gpointer data);
 
+void functional_notebook_select_playlist();
+void functional_notebook_select_database();
+void functional_notebook_select_config();
+void functional_notebook_select_playlists();
+
+gboolean functional_notebook_playlist_selected();
+gboolean functional_notebook_database_selected();
+gboolean functional_notebook_config_selected();
+gboolean functional_notebook_playlists_selected();
+
 /* this one is in tooltips.c */
 void gui_create_tooltips();
 
@@ -115,6 +124,8 @@ enum {
   NUM_QSEARCH
 };
 
-#define TRACKNAME_SCROLL_START		50
+void glurp_switch_functional_page(GtkWidget* focus, gboolean next);
+#define TRACKNAME_SCROLL_START    50
 
 #endif /* __GUI_H */
+// vim: et sw=2 smarttab
