@@ -29,8 +29,9 @@ void player_stop();
 void player_prev();
 void player_next();
 
-#define STOPPED		(glurp->play_state == MPD_STATUS_STATE_STOP)
-#define PLAYING		(glurp->play_state == MPD_STATUS_STATE_PLAY)
-#define PAUSED		(glurp->play_state == MPD_STATUS_STATE_PAUSE)
+#define STOPPED    (mpd_player_get_state(glurp->mpd) == MPD_PLAYER_STOP)
+#define PLAYING    (mpd_player_get_state(glurp->mpd) == MPD_PLAYER_PLAY)
+#define PAUSED     (mpd_player_get_state(glurp->mpd) == MPD_PLAYER_PAUSE)
 
 #endif /* __PLAYER_H */
+// vim: et sw=2 smarttab
