@@ -26,17 +26,19 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <libmpd/libmpd-strfsong.h>
 
 #include "structs.h"
 #include "support.h"
 #include "comm.h"
 #include "gui.h"
+#include "gui-callbacks.h"
 
-extern GladeXML *guixml, *addxml;
+#include <libmpd/libmpd-player.h>
+extern GtkBuilder *builder;
 extern GlurpState *glurp;
 
 void debug_real (const char *file, const int line, const char *function, const char *msg, ...) {
@@ -55,7 +57,7 @@ void debug_real (const char *file, const int line, const char *function, const c
 void statusbar_print(const char *string, ...) {
   char str[129];
   va_list va;
-  GtkWidget *sb = glade_xml_get_widget(guixml, "statusbar_main");
+  GtkWidget *sb = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar_main"));
 
   va_start(va, string);
   g_vsnprintf(str, sizeof(str)-1, string, va);
@@ -73,7 +75,7 @@ gboolean statusbar_reset(gpointer msg) {
   if( glurp->progress_dragging ) return FALSE;
 
   if( *(gint*)msg == glurp->statusbar_status ) {
-    sb = glade_xml_get_widget(guixml, "statusbar_main");
+    sb = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar_main"));
     gtk_statusbar_push(GTK_STATUSBAR(sb), 0, status_string());
     glurp->statusbar_status = 0;
   }
@@ -90,7 +92,7 @@ void title_print(GtkWidget *window, const char *string, ...) {
   va_start(va, string);
   g_vsnprintf(str, sizeof(str)-1, string, va);
 
-  if(!string || !str || !strlen(str)) str2 = g_strdup_printf("%s", GLURP_TITLE_PREFIX);
+  if(!string || !strlen(str)) str2 = g_strdup_printf("%s", GLURP_TITLE_PREFIX);
   else str2 = g_strdup_printf("%s :: %s", GLURP_TITLE_PREFIX, str);
 
   gtk_window_set_title(GTK_WINDOW(window), str2);
@@ -98,27 +100,22 @@ void title_print(GtkWidget *window, const char *string, ...) {
 }
 
 gchar *status_string() {
-  mpd_Status *mpdstatus;
+  MpdState state = mpd_player_get_state(glurp->mpd);
 
-  if(!CONNECTED) return "Not connected to server";
+  if(!mpd_check_connected(glurp->mpd)) return "Not connected to server";
 
-  mpdstatus = get_status(TRUE);
-
-  if(mpdstatus->state == MPD_STATUS_STATE_PLAY) return "Connected to server, playing";
-  if(mpdstatus->state == MPD_STATUS_STATE_PAUSE) return "Connected to server, paused";
-  if(mpdstatus->state == MPD_STATUS_STATE_STOP) return "Connected to server, stopped";
+  if (glurp->updating_db) {
+    if(state == MPD_PLAYER_PLAY)  return "Connected to server, Updating DB, Playing";
+    if(state == MPD_PLAYER_PAUSE) return "Connected to server, Updating DB, Paused";
+    if(state == MPD_PLAYER_STOP)  return "Connected to server, Updating DB, Stopped";
+  } else {
+    if(state == MPD_PLAYER_PLAY)  return "Connected to server, Playing";
+    if(state == MPD_PLAYER_PAUSE) return "Connected to server, Paused";
+    if(state == MPD_PLAYER_STOP)  return "Connected to server, Stopped";
+  }
   return "Connected to server, unknown state";
 }
 
-GlurpSong *get_nth_song_from_playlist(gint pos) {
-  gint i;
-  GlurpSong *s;
-
-  for( i = 0, s = glurp->playlist; s && i<pos; i++, s = s->next ) {}
-
-  return s;
-}
-
 /* this will return a pointer to the first character after last '/' in path */
 gchar *strip_dirs(gchar *path) {
   gchar *c = path, *s = path;
@@ -130,10 +127,56 @@ gchar *strip_dirs(gchar *path) {
   return s+1;
 }
 
-gchar *glade_path() {
-  gchar *path;
+GtkWidget* get_image_from_name(gchar* name) {
+  gchar* path;
+  GtkWidget* retval;
+#ifdef WIN32
+  gchar *packagedir;
+  packagedir = g_win32_get_package_installation_directory("glurp",NULL);
+  debug("Got %s as package installation dir", packagedir);
+  path = g_build_filename(packagedir,"data",name,NULL);
+  g_free(packagedir);
+#else
+  path = g_strdup_printf(DATA_DIR"pixmaps/%s", name);
+#endif
+  debug("Using %s for image %s",path, name);
+  retval = gtk_image_new_from_file(path);
+  g_free(path);
+  return retval;
+}
 
-  path = g_strdup_printf(DATADIR"glurp.glade");
+GdkPixbuf *get_pixbuf_from_name(gchar* name) {
+  gchar *path;
+  GdkPixbuf *retval;
+#ifdef WIN32
+  gchar *packagedir;
+  packagedir = g_win32_get_package_installation_directory("glurp",NULL);
+  debug("Got %s as package installation dir", packagedir);
+  path = g_build_filename(packagedir,"data",name,NULL);
+  g_free(packagedir);
+#else
+  path = g_strdup_printf(DATA_DIR"pixmaps/%s", name);
+#endif
+  debug("Using %s for image %s",path, name);
+  retval = gdk_pixbuf_new_from_file(path,NULL);
+  g_free(path);
+  return retval;
+}
+
+ 
+gchar *builder_path() {
+  gchar *path;
+#ifdef WIN32
+  gchar *packagedir;
+  packagedir = g_win32_get_package_installation_directory_utf8("glurp",NULL);
+  debug("Got %s as package installation dir", packagedir);
+  
+  path = g_build_filename(packagedir,"data", "glurp.glade",NULL);
+#else
+  if (g_file_test("./glurp.glade", G_FILE_TEST_EXISTS)) return g_strdup("./glurp.glade");
+  path = g_strdup_printf(DATA_DIR"glurp.glade");
+#endif
+  
   if(!g_file_test(path, G_FILE_TEST_EXISTS)) {
     debug("file '%s' does not exist", path);
     g_free(path);
@@ -160,90 +203,41 @@ gchar *glurp_filename(gchar *path) {
   return dirs[i];
 }
 
-GlurpSong *get_song_by_pos(gint pos) {
-  gint i;
-  GlurpSong *s = NULL;
-
-  for( i = 0, s = glurp->playlist; i < pos && s; i++, s = s->next ) {}
-
-  return (s ? s : NULL);
-}
-
-GlurpSong *get_song_by_id(gint id) {
-  GlurpSong *s = NULL;
-
-  for( s = glurp->playlist; s; s = s->next ) {
-    if( s->id == id ) {
-      debug("Found it, returning");
-      return s;
-    }
-  }
-
-  return NULL;
-}
-
-gint get_song_pos(GlurpSong *song) {
-  GlurpSong *s = NULL;
-  gint i;
-
-  for( i = 0, s = glurp->playlist; s; s = s->next, i++ ) {
-    if( s == song ) {
-      debug("Found song position: %d", i);
-      return i;
-    }
-  }
-
-  debug("Couldn't find song position");
-  return -1;
-}
-
-gint get_num_songs() {
-  GlurpSong *s = NULL;
-  gint i;
-
-  for( i = 0, s = glurp->playlist; s; s = s->next, i++ ) {}
-  return i;
-}
-
-void update_song(mpd_Song *song) {
-  debug("calling glurp_update_song()");
-  glurp_update_song(song);
-  debug("calling gui_update_song()");
-  gui_update_song(song->id);
-}
-
 void add_song(mpd_Song *song) {
-  GlurpSong *gsong = NULL, *s = NULL;
-
-  if( get_song_by_id(song->id) ) {
-    debug("Already added, ignoring");
-    return;
+  gint curlast = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(glurp->gui_playlist), NULL) - 1;
+  gint needed = song->pos - curlast ;
+  GtkTreeIter iter;
+  gchar title[1024];
+    
+  
+  if (needed>0) {
+    for (;needed > 0; needed--) {
+      /* need to add some positions in the liststore */
+      gtk_list_store_append(glurp->gui_playlist, &iter);
+    }
+  } else {
+    gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(glurp->gui_playlist), &iter, NULL, song->pos);
   }
 
-  gsong = malloc(sizeof(GlurpSong));
-  gsong->file = g_strdup(song->file);
-  gsong->artist = g_strdup(song->artist);
-  gsong->title = g_strdup(song->title);
-  gsong->album = g_strdup(song->album);
-  gsong->track = g_strdup(song->track);
-  gsong->name = g_strdup(song->name);
-  gsong->time = song->time;
-  gsong->pos = song->pos;
-  gsong->id = song->id;
-  gsong->next = NULL;
+  mpd_song_markup(title, 1023, "[%artist% - %title%]|%name%|%file%", song);
 
-  for(s = glurp->playlist; s && s->next; s = s->next) {}
-
-  if(s) s->next = gsong;
-  else glurp->playlist = gsong;
+  gtk_list_store_set(glurp->gui_playlist, &iter,
+    PL_POS, song->pos + 1,
+    PL_TITLE, title,
+    PL_ID, song->id,
+    -1);
 }
 
 void debug_print_playlist() {
-  GlurpSong *s = NULL;
-
+  GtkTreeIter iter;
+  gchar* title;
+  gint id;
+  gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(glurp->gui_playlist), &iter, NULL, 0);
   debug("-----------------------------------------------");
-  for( s = glurp->playlist; s; s = s->next )
-    debug("(%d) %s", s->id, s->file);
+  do {
+    gtk_tree_model_get(GTK_TREE_MODEL(glurp->gui_playlist), &iter, PL_ID, &id, PL_TITLE, &title, -1);
+    debug("(%d) %s", id, title);
+  } while (gtk_tree_model_iter_next(GTK_TREE_MODEL(glurp->gui_playlist), &iter));
   debug("-----------------------------------------------");
 }
 
@@ -336,3 +330,58 @@ void push_stream(gchar *url) {
     prepend_stream(url);
 //  else lift_stream(s);
 }
+
+void pull_stream(gchar* url) {
+  GlurpStream *s = NULL;
+  GlurpStream *p = NULL;
+
+  if ( !strcmp(url, glurp->stream_history->url) ) {
+    s = glurp->stream_history;
+    glurp->stream_history = s->next;
+  } else {
+    for( p = glurp->stream_history, s = glurp->stream_history->next; s; p = p->next, s = s->next ) {
+      if( !strcmp(url, s->url) )
+        break;
+    }
+    p->next = s->next;
+  }
+  if (s) {
+    g_free(s->url);
+    g_free(s);
+  }
+}
+
+void sigint_handler(int s) {
+  debug("SIGINT received, exiting gracefully");
+  on_ui_quit(NULL, NULL);
+}
+
+char *remove_extension_and_basepath(const char *filename)
+{
+  int i = 0;
+  char *buf = NULL;
+  if(filename == NULL)
+  {
+    return NULL;
+  }
+  buf  = g_path_get_basename(filename);
+
+  if(buf != NULL)
+  {
+    /* replace _ with spaces */
+    for(i=0; i< strlen(buf);i++)
+    {
+      if(buf[i] == '_') buf[i] = ' ';
+    }
+    for(i=strlen(buf);buf[i] != '.';i--);
+    /* cut of the extention */
+    if(i > 0)
+    {
+      gchar *buf2 = g_strndup(buf, i);
+      g_free(buf);
+      return buf2;
+    }
+  }
+  return buf;
+}
+// vim: et sw=2 smarttab
